---
title: <span class="badge object-type-scalar"></span> PebibitsPerSecond
---
# <span class="badge object-type-scalar"></span> PebibitsPerSecond

Data rate: pebibits/sec

## Definition

```python
# Data rate: pebibits/sec
PebibitsPerSecond: typing.Literal["Pibits"] = "Pibits"
```
